/**
 * apeman app to server OpenAPI document.
 * @memberof module:apeman-app-spec/lib
 * @function apemanAppSpec
 * @param {object} [options] - Optional settings.
 * @returns {function} - Defined app function.
 */

'use strict'

const assert = require('assert')
const path = require('path')
const argx = require('argx')
const url = require('url')
const querystring = require('querystring')
const static_ = require('apeman-app-static')

const debug = require('debug')('apeman:app:oai')

const ASSET_DIR = path.resolve(__dirname, '../assets')

/** @lends create */
function create (defaultUrl, options = {}) {
  let args = argx(arguments)
  defaultUrl = args.shift('string')

  let staticApp = static_(ASSET_DIR)

  if (defaultUrl) {
    debug(`Register spec default url: ${defaultUrl}`)
  }

  /**
   * Defined app.
   * @function app
   * @param {object} req - Request object.
   * @param {object} res - Response object.
   * @param {function} next - Pass to next handler.
   */
  function app (req, res, next) {
    assert.ok(res.redirect, 'res.redirect not found. Use "apeman-app-redirect" before this.')
    let data = url.parse(req.url)
    let query = querystring.parse(data.query)
    if (data.pathname === '/') {
      if (!query.url && defaultUrl) {
        res.redirect(`?url=${encodeURIComponent(defaultUrl)}`)
        return
      }
    }
    staticApp(req, res, next)
  }

  // Description of this app.
  app.$desc = 'App for api spec page.'

  return app
}

module.exports = create
