/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const co = require('co')
const apemanport = require('apemanport')
const apemanrequest = require('apemanrequest')
const apemanApp = require('apeman-app')
const assert = require('assert')

describe('create', function () {
  this.timeout(60 * 10000 * 1000)
  let server, baseUrl
  let request = apemanrequest.create({})
  before(() => co(function * () {
    let app = create('http://petstore.swagger.io/v2/swagger.json', {})
    assert.ok(app)
    let port = yield apemanport.find()
    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              require('apeman-app-header')(),
              require('apeman-app-location')(),
              require('apeman-app-redirect')()
            ],
            '/spec': [
              app
            ]
          }
        }
      }
    })
    baseUrl = `http://localhost:${port}`
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create', () => co(function * () {
    let res = yield request({
      method: 'GET',
      url: `${baseUrl}/spec`
    })
    let { body } = res
    assert.equal(res.statusCode, 200)
  }))
})

/* global describe, before, after, it */

